@@ -41,6 +41,7 @@ class Timer : public Node {
 	bool autostart = false;
 	bool processing = false;
 	bool paused = false;
+	bool ignore_time_scale = false;
 
 	double time_left = -1.0;
 
@@ -69,6 +70,9 @@ public:
 	void set_paused(bool p_paused);
 	bool is_paused() const;
 
+	void set_ignore_time_scale(bool p_ignore);
+	bool is_ignoring_time_scale();
+
 	bool is_stopped() const;
 
 	double get_time_left() const;
